@@ -9,6 +9,7 @@
 #include <rtt/typekit/RealTimeTypekit.hpp>
 #include <rtt/base/PortInterface.hpp>
 #include <rtt/transports/corba/TransportPlugin.hpp>
+#include <rtt/transports/corba/CorbaConnPolicy.hpp>
 #include <rtt/plugin/PluginLoader.hpp>
 
 #include <rtt/base/OutputPortInterface.hpp>
@@ -223,7 +224,7 @@ static VALUE task_context_attribute_names(VALUE self)
         corba_blocking_fct_call_with_result(bind(&_objref_CConfigurationInterface::getAttributeList,(_objref_CConfigurationInterface*)context.main_service));
     for (unsigned int i = 0; i != names->length(); ++i)
     {
-        #if RTT_VERSION_GTE(2,9,0)
+        #if RTT_VERSION_GTE(2,8,99)
             CORBA::String_var name = names[i].name;
         #else
             CORBA::String_var name = names[i];
@@ -238,7 +239,7 @@ static VALUE task_context_operation_names(VALUE self)
     RTaskContext& context = get_wrapped<RTaskContext>(self);
 
     VALUE result = rb_ary_new();
-    #if RTT_VERSION_GTE(2,9,0)
+    #if RTT_VERSION_GTE(2,8,99)
         RTT::corba::COperationInterface::COperationDescriptions_var names =
                 corba_blocking_fct_call_with_result(bind(&_objref_COperationInterface::getOperations,(_objref_COperationInterface*)context.main_service));
     #else
@@ -248,7 +249,7 @@ static VALUE task_context_operation_names(VALUE self)
 
     for (unsigned int i = 0; i != names->length(); ++i)
     {
-        #if RTT_VERSION_GTE(2,9,0)
+        #if RTT_VERSION_GTE(2,8,99)
             CORBA::String_var name = names[i].name;
         #else
             CORBA::String_var name = names[i];
@@ -395,7 +396,7 @@ static VALUE port_connected_p(VALUE self)
 
 static RTT::corba::CConnPolicy policyFromHash(VALUE options)
 {
-    RTT::corba::CConnPolicy result;
+    RTT::corba::CConnPolicy result = toCORBA(RTT::ConnPolicy());
     VALUE conn_type_value = rb_hash_aref(options, ID2SYM(rb_intern("type")));
     VALUE conn_type = SYM2ID(conn_type_value);
     if (conn_type == rb_intern("data"))
