@@ -45,7 +45,8 @@ module Orocos
             Hash['rock_task_model' => (task.model.name || ''),
                 'rock_task_name' => task.name,
                 'rock_task_object_name' => name,
-                'rock_orocos_type_name' => orocos_type_name]
+                'rock_orocos_type_name' => orocos_type_name,
+                'rock_cxx_type_name' => orocos_type_name]
         end
 
         def ensure_type_available(options = Hash.new)
